==> testdisk_7.1.orig.tar.bz2: testdisk-7.1/src/lang/qphotorec.pt.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="pt" version="2.1">
<context>
    <name>QPhotorec</name>
    <message>
        <location filename="src/qphotorec.cpp" line="125"/>
        <source>QPhotoRec</source>
        <translation>QPhotoRec</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="156"/>
        <location filename="src/qphotorec.cpp" line="518"/>
        <source>Please select a destination to save the recovered files to.</source>
        <translation>Por favor selecionar o destino para salvar os arquivos recuperados.</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="170"/>
        <source>Please select a raw file</source>
        <translation>Por favor selecionar o arquivo raw</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="172"/>
        <source>Raw Files (*.dd *.raw *.img)</source>
        <translation>Arquivos Raw (*.dd *.raw *.img)</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="259"/>
        <source>Sys=</source>
        <translation>Sys=</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="261"/>
        <source>Unknown</source>
        <translation>Desconhecido</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="377"/>
        <source>No harddisk found</source>
        <translation>Disco rígido não encontrado</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="379"/>
        <source>No harddisk found
You need to be administrator to use this program.
Under Win9x, use the DOS version instead.
Under Vista or later, select this program, right-click and choose &quot;Run as administrator&quot;.</source>
        <translation>Disco rígido não encontrado
Você precisa ser um administrador para usar este programa.
Abaixo o Win9x, use a versão DOS ao invés
Abaixo o Vista ou próximos, selecionar o programa, clique com o direito e selecione &quot;Executar como administrador&quot;.</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="388"/>
        <source>No harddisk found
You need to be root to use PhotoRec.</source>
        <translation>Disco rígido não encontrado.
Você precisa ser root para usar PhotoRec.</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="393"/>
        <source>No Disk!</source>
        <translation>Sem disco!</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="452"/>
        <source>Add a raw disk image...</source>
        <translation>Adicionar imagem de disco raw...</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="458"/>
        <source>PhotoRec is free software, and comes with ABSOLUTELY NO WARRANTY.</source>
        <translation>PhotoRec é um software livre, e não vem com ABSOLUTAMENTE NENHUMA GARANTIA.</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="459"/>
        <source>Please select a media to recover from</source>
        <translation>Por favor selecionar a midia para recuperar</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="462"/>
        <source>Disk capacity must be correctly detected for a successful recovery.
If a disk listed above has an incorrect size, check HD jumper settings and BIOS
detection, and install the latest OS patches and disk drivers.</source>
        <translation>A capacidade do disco deve ser corretamente detectado para uma recuperação bem sucedida.
Se o disco listado abaixo não tem o tamanho certo, verificar o jumper do HD nas configurações da BIOS
detecar, e instalar o ultimo patch do SO e drivers do disco.</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="469"/>
        <source>Flags</source>
        <translation>Flags</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="470"/>
        <source>Type</source>
        <translation>Tipo</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="471"/>
        <source>File System</source>
        <translation>Sistema de arquivos</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="472"/>
        <source>Size</source>
        <translation>Tamanho</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="473"/>
        <source>Label</source>
        <translation>Etiqueta</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="488"/>
        <source>File System type</source>
        <translation>Tipo de sistema de arquivos</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="489"/>
        <source>ext2/ext3/ext4 filesystem</source>
        <translation>Sistemas de arquivos ext2/ext3/ext4</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="490"/>
        <source>FAT/NTFS/HFS+/ReiserFS/...</source>
        <translation>FAT/NTFS/HFS+/ReiserFS/...</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="494"/>
        <source>Free: Scan for file from unallocated space only</source>
        <translation>Livre: Esconear por arquivos de espaços não alocados somente.</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="495"/>
        <source>Whole: Extract files from whole partition</source>
        <translation>Inteiro: Extrair arquivos da partição inteira</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="522"/>
        <source>&amp;Browse</source>
        <translation>&amp;Browse</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="538"/>
        <source>&amp;Search</source>
        <translation>&amp;Pesquisar</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="541"/>
        <source>&amp;About</source>
        <translation>&amp;Sobre</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="542"/>
        <source>&amp;File Formats</source>
        <translation>&amp;Formatos de arquivos</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="642"/>
        <source>Destination:</source>
        <translation>Destino:</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="647"/>
        <source>Recovery completed</source>
        <translation>Recuperação completada</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="652"/>
        <source>Bruteforce %1 sectors remaining (test %2)</source>
        <translation>Bruteforce %1 setores restantes (teste %2)</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="660"/>
        <source>Pass %1 - Reading sector %2/%3</source>
        <translation>Passar %1 - Lendo setor %2/%3</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="665"/>
        <source>%1/10 headers found</source>
        <translation>%1/10 headers encontrados</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="667"/>
        <source>%1 files found</source>
        <translation>%1 arquivos encontrados</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="540"/>
        <location filename="src/qphotorec.cpp" line="762"/>
        <source>&amp;Quit</source>
        <translation>&amp;Sair</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="750"/>
        <source>File family</source>
        <translation>Familia do arquivo</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="751"/>
        <source>Number of files recovered</source>
        <translation>Número de arquivos recuperados</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="834"/>
        <source>QPhotoRec: Failed to create file!</source>
        <translation>QPhotoRec: Falha ao criar o arquivo!</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="835"/>
        <source>Failed to create file! Please choose another destination</source>
        <translation>Falha ao criar o arquivo! Por favor selecionar outro destino</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="854"/>
        <source>QPhotoRec: Not enough space!</source>
        <translation>QPhotoRec: Sem espaço suficiente!</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="855"/>
        <source>There is not enough space left! Please free disk space and/or choose another destination</source>
        <translation>Não tem espaço suficiente! Por favor mais espaço em disco e/ou selecione outro destino</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="924"/>
        <source>QPhotoRec is is free software: you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 2 of the License, or (at your option) any later version.

QPhotoRec is is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License along with QPhotoRec.  If not, see &lt;http://www.gnu.org/licenses/&gt;.</source>
        <translation>QPhotoRec é um software livre: você pode redistribuir e/ou modificar sob os termos de licença GNU General Public License conforme publicado pelo Free Software Foundation, também versão 2 da licença, ou (de sua opinião) qualquer versão recente.

QPhotoRec é distribuido na esperança de ser util, porém sem qualquer garantia; mesmo sem a garantia implícita de COMERCIALIZAÇÃO ou ADEQUAÇÃO A UM DETERMINADO FIM. Veja o GNU General Public License para mais detalhes.

Você deve receber uma cópia do licença GNU durante o uso de QPhotoRec. Se não, visite &lt;https://www.gnu.org/licenses/&gt;.</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="925"/>
        <source>QPhotoRec: About</source>
        <translation>QPhotoRec: Sobre</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="954"/>
        <source>File Formats</source>
        <translation>Formatos de arquivos</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="957"/>
        <source>&amp;Reset</source>
        <translation>&amp;Reconfigurar</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="958"/>
        <source>Res&amp;tore</source>
        <translation>&amp;Restaurar</translation>
    </message>
</context>
</TS>

==> testdisk_7.2.orig.tar.bz2: testdisk-7.2/src/lang/qphotorec.pt.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="pt" version="2.1">
<context>
    <name>QPhotorec</name>
    <message>
        <location filename="src/qphotorec.cpp" line="125"/>
        <source>QPhotoRec</source>
        <translation>QPhotoRec</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="156"/>
        <location filename="src/qphotorec.cpp" line="521"/>
        <source>Please select a destination to save the recovered files to.</source>
        <translation>Por favor selecionar o destino para salvar os arquivos recuperados.</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="170"/>
        <source>Please select a raw file</source>
        <translation>Por favor selecionar o arquivo raw</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="172"/>
        <source>Raw Files (*.dd *.raw *.img)</source>
        <translation>Arquivos Raw (*.dd *.raw *.img)</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="259"/>
        <source>Sys=</source>
        <translation>Sys=</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="261"/>
        <source>Unknown</source>
        <translation>Desconhecido</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="377"/>
        <source>No hard disk found</source>
        <oldsource>No harddisk found</oldsource>
        <translation>Disco rígido não encontrado</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="379"/>
        <source>No hard disk found
You need to be administrator to use this program.
Under Win9x, use the DOS version instead.
Under Vista or later, select this program, right-click and choose &quot;Run as administrator&quot;.</source>
        <oldsource>No harddisk found
You need to be administrator to use this program.
Under Win9x, use the DOS version instead.
Under Vista or later, select this program, right-click and choose &quot;Run as administrator&quot;.</oldsource>
        <translation>Disco rígido não encontrado
Você precisa ser um administrador para usar este programa.
Abaixo o Win9x, use a versão DOS ao invés
Abaixo o Vista ou próximos, selecionar o programa, clique com o direito e selecione &quot;Executar como administrador&quot;.</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="388"/>
        <source>No hard disk found
You need to be root to use PhotoRec.</source>
        <oldsource>No harddisk found
You need to be root to use PhotoRec.</oldsource>
        <translation>Disco rígido não encontrado.
Você precisa ser root para usar PhotoRec.</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="393"/>
        <source>No Disk!</source>
        <translation>Sem disco!</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="455"/>
        <source>Add a raw disk image...</source>
        <translation>Adicionar imagem de disco raw...</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="461"/>
        <source>PhotoRec is free software, and comes with ABSOLUTELY NO WARRANTY.</source>
        <translation>PhotoRec é um software livre, e não vem com ABSOLUTAMENTE NENHUMA GARANTIA.</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="462"/>
        <source>Please select a media to recover from</source>
        <translation>Por favor selecionar a midia para recuperar</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="465"/>
        <source>Disk capacity must be correctly detected for a successful recovery.
If a disk listed above has an incorrect size, check HD jumper settings and BIOS
detection, and install the latest OS patches and disk drivers.</source>
        <translation>A capacidade do disco deve ser corretamente detectado para uma recuperação bem sucedida.
Se o disco listado abaixo não tem o tamanho certo, verificar o jumper do HD nas configurações da BIOS
detecar, e instalar o ultimo patch do SO e drivers do disco.</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="472"/>
        <source>Flags</source>
        <translation>Flags</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="473"/>
        <source>Type</source>
        <translation>Tipo</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="474"/>
        <source>File System</source>
        <translation>Sistema de arquivos</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="475"/>
        <source>Size</source>
        <translation>Tamanho</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="476"/>
        <source>Label</source>
        <translation>Etiqueta</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="491"/>
        <source>File System type</source>
        <translation>Tipo de sistema de arquivos</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="492"/>
        <source>ext2/ext3/ext4 filesystem</source>
        <translation>Sistemas de arquivos ext2/ext3/ext4</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="493"/>
        <source>FAT/NTFS/HFS+/ReiserFS/...</source>
        <translation>FAT/NTFS/HFS+/ReiserFS/...</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="497"/>
        <source>Free: Scan for file from unallocated space only</source>
        <translation>Livre: Esconear por arquivos de espaços não alocados somente.</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="498"/>
        <source>Whole: Extract files from whole partition</source>
        <translation>Inteiro: Extrair arquivos da partição inteira</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="525"/>
        <source>&amp;Browse</source>
        <translation>&amp;Browse</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="541"/>
        <source>&amp;Search</source>
        <translation>&amp;Pesquisar</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="544"/>
        <source>&amp;About</source>
        <translation>&amp;Sobre</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="545"/>
        <source>&amp;File Formats</source>
        <translation>&amp;Formatos de arquivos</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="645"/>
        <source>Destination:</source>
        <translation>Destino:</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="650"/>
        <source>Recovery completed</source>
        <translation>Recuperação completada</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="655"/>
        <source>Bruteforce %1 sectors remaining (test %2)</source>
        <translation>Bruteforce %1 setores restantes (teste %2)</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="663"/>
        <source>Pass %1 - Reading sector %2/%3</source>
        <translation>Passar %1 - Lendo setor %2/%3</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="668"/>
        <source>%1/10 headers found</source>
        <translation>%1/10 headers encontrados</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="670"/>
        <source>%1 files found</source>
        <translation>%1 arquivos encontrados</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="753"/>
        <source>File family</source>
        <translation>Familia do arquivo</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="543"/>
        <location filename="src/qphotorec.cpp" line="765"/>
        <source>&amp;Quit</source>
        <translation>&amp;Sair</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="754"/>
        <source>Number of files recovered</source>
        <translation>Número de arquivos recuperados</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="837"/>
        <source>QPhotoRec: Failed to create file!</source>
        <translation>QPhotoRec: Falha ao criar o arquivo!</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="838"/>
        <source>Failed to create file! Please choose another destination</source>
        <translation>Falha ao criar o arquivo! Por favor selecionar outro destino</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="857"/>
        <source>QPhotoRec: Not enough space!</source>
        <translation>QPhotoRec: Sem espaço suficiente!</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="858"/>
        <source>There is not enough space left! Please free disk space and/or choose another destination</source>
        <translation>Não tem espaço suficiente! Por favor mais espaço em disco e/ou selecione outro destino</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="927"/>
        <source>QPhotoRec is free software: you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 2 of the License, or (at your option) any later version.

QPhotoRec is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License along with QPhotoRec.  If not, see &lt;http://www.gnu.org/licenses/&gt;.</source>
        <oldsource>QPhotoRec is is free software: you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 2 of the License, or (at your option) any later version.

QPhotoRec is is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License along with QPhotoRec.  If not, see &lt;http://www.gnu.org/licenses/&gt;.</oldsource>
        <translation>QPhotoRec é um software livre: você pode redistribuir e/ou modificar sob os termos de licença GNU General Public License conforme publicado pelo Free Software Foundation, também versão 2 da licença, ou (de sua opinião) qualquer versão recente.

QPhotoRec é distribuido na esperança de ser util, porém sem qualquer garantia; mesmo sem a garantia implícita de COMERCIALIZAÇÃO ou ADEQUAÇÃO A UM DETERMINADO FIM. Veja o GNU General Public License para mais detalhes.

Você deve receber uma cópia do licença GNU durante o uso de QPhotoRec. Se não, visite &lt;https://www.gnu.org/licenses/&gt;.</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="928"/>
        <source>QPhotoRec: About</source>
        <translation>QPhotoRec: Sobre</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="957"/>
        <source>File Formats</source>
        <translation>Formatos de arquivos</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="960"/>
        <source>&amp;Reset</source>
        <translation>&amp;Reconfigurar</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="961"/>
        <source>Res&amp;tore</source>
        <translation>&amp;Restaurar</translation>
    </message>
</context>
</TS>
